==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/FlexPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class FlexPersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent<A>{
  public FlexPersistentVolumeSourceFluentImpl() {
  }
  public FlexPersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.FlexPersistentVolumeSource instance) {
    this.withDriver(instance.getDriver()); 
    this.withFsType(instance.getFsType()); 
    this.withOptions(instance.getOptions()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
  }
  private java.lang.String driver;
  private java.lang.String fsType;
  private java.util.Map<java.lang.String,java.lang.String> options;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.SecretReferenceBuilder secretRef;
  public java.lang.String getDriver() {
    return this.driver;
  }
  public A withDriver(java.lang.String driver) {
    this.driver=driver; return (A) this;
  }
  public java.lang.Boolean hasDriver() {
    return this.driver != null;
  }
  
  /**
   * Method is deprecated. use withDriver instead.
   */
  @java.lang.Deprecated
  public A withNewDriver(java.lang.String arg0) {
    return (A)withDriver(new String(arg0));
  }
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public A addToOptions(java.lang.String key,java.lang.String value) {
    if(this.options == null && key != null && value != null) { this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.options.put(key, value);} return (A)this;
  }
  public A addToOptions(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.options == null && map != null) { this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.options.putAll(map);} return (A)this;
  }
  public A removeFromOptions(java.lang.String key) {
    if(this.options == null) { return (A) this; }
    if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
  }
  public A removeFromOptions(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.options == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getOptions() {
    return this.options;
  }
  public <K,V>A withOptions(java.util.Map<java.lang.String,java.lang.String> options) {
    if (options == null) { this.options =  null;} else {this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(options);} return (A) this;
  }
  public java.lang.Boolean hasOptions() {
    return this.options != null;
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.SecretReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name,java.lang.String namespace) {
    return (A)withSecretRef(new SecretReference(name, namespace));
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return new io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.SecretReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FlexPersistentVolumeSourceFluentImpl that = (FlexPersistentVolumeSourceFluentImpl) o;
    if (driver != null ? !driver.equals(that.driver) :that.driver != null) return false;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(driver,  fsType,  options,  readOnly,  secretRef,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.SecretReferenceFluentImpl<io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.SecretReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.SecretReferenceBuilder builder;
    public N and() {
      return (N) FlexPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/FlexPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class FlexPersistentVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent<A>{
  public FlexPersistentVolumeSourceFluentImpl() {
  }
  public FlexPersistentVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.FlexPersistentVolumeSource instance) {
    this.withDriver(instance.getDriver()); 
    this.withFsType(instance.getFsType()); 
    this.withOptions(instance.getOptions()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String driver;
  private java.lang.String fsType;
  private java.util.Map<java.lang.String,java.lang.String> options;
  private java.lang.Boolean readOnly;
  private io.fabric8.kubernetes.api.model.SecretReferenceBuilder secretRef;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getDriver() {
    return this.driver;
  }
  public A withDriver(java.lang.String driver) {
    this.driver=driver; return (A) this;
  }
  public java.lang.Boolean hasDriver() {
    return this.driver != null;
  }
  
  /**
   * Method is deprecated. use withDriver instead.
   */
  @java.lang.Deprecated
  public A withNewDriver(java.lang.String arg0) {
    return (A)withDriver(new String(arg0));
  }
  public java.lang.String getFsType() {
    return this.fsType;
  }
  public A withFsType(java.lang.String fsType) {
    this.fsType=fsType; return (A) this;
  }
  public java.lang.Boolean hasFsType() {
    return this.fsType != null;
  }
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0) {
    return (A)withFsType(new String(arg0));
  }
  public A addToOptions(java.lang.String key,java.lang.String value) {
    if(this.options == null && key != null && value != null) { this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.options.put(key, value);} return (A)this;
  }
  public A addToOptions(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.options == null && map != null) { this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.options.putAll(map);} return (A)this;
  }
  public A removeFromOptions(java.lang.String key) {
    if(this.options == null) { return (A) this; }
    if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
  }
  public A removeFromOptions(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.options == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getOptions() {
    return this.options;
  }
  public <K,V>A withOptions(java.util.Map<java.lang.String,java.lang.String> options) {
    if (options == null) { this.options =  null;} else {this.options = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(options);} return (A) this;
  }
  public java.lang.Boolean hasOptions() {
    return this.options != null;
  }
  public java.lang.Boolean getReadOnly() {
    return this.readOnly;
  }
  public A withReadOnly(java.lang.Boolean readOnly) {
    this.readOnly=readOnly; return (A) this;
  }
  public java.lang.Boolean hasReadOnly() {
    return this.readOnly != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.SecretReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(java.lang.String name,java.lang.String namespace) {
    return (A)withSecretRef(new SecretReference(name, namespace));
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return new io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.SecretReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FlexPersistentVolumeSourceFluentImpl that = (FlexPersistentVolumeSourceFluentImpl) o;
    if (driver != null ? !driver.equals(that.driver) :that.driver != null) return false;
    if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(driver,  fsType,  options,  readOnly,  secretRef,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.SecretReferenceFluentImpl<io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<N>> implements io.fabric8.kubernetes.api.model.FlexPersistentVolumeSourceFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.SecretReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.SecretReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.SecretReferenceBuilder builder;
    public N and() {
      return (N) FlexPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
